# Copyright 2022 – present, Jakob Bagterp. BSD 3-Clause license and refer to LICENSE file.

from ... import helper
from ...model.abc.mkdocstrings import MkDocstringsWrapper_ABC
from ...model.foreground.bright_color import BrightColor


def bright_black(text: str) -> None:
    """Prints full line of bright black text."""

    helper.print.color(text, color=BrightColor.BLACK)


def bright_red(text: str) -> None:
    """Prints full line of bright red text."""

    helper.print.color(text, color=BrightColor.RED)


def bright_green(text: str) -> None:
    """Prints full line of bright green text."""

    helper.print.color(text, color=BrightColor.GREEN)


def bright_yellow(text: str) -> None:
    """Prints full line of bright yellow text."""

    helper.print.color(text, color=BrightColor.YELLOW)


def bright_blue(text: str) -> None:
    """Prints full line of bright blue text."""

    helper.print.color(text, color=BrightColor.BLUE)


def bright_magenta(text: str) -> None:
    """Prints full line of bright magenta text."""

    helper.print.color(text, color=BrightColor.MAGENTA)


def bright_cyan(text: str) -> None:
    """Prints full line of bright cyan text."""

    helper.print.color(text, color=BrightColor.CYAN)


def bright_white(text: str) -> None:
    """Prints full line of bright white text."""

    helper.print.color(text, color=BrightColor.WHITE)


class MkDocstringsWrapper(MkDocstringsWrapper_ABC):
    def bright_black(self, text: str) -> None:
        """Prints full line of bright black text.

        Args:
            text (str): Text to be printed with color.

        Example:
            ```python title="" linenums="1"
            from colorist import bright_black

            bright_black("This is BRIGHT BLACK!")
            ```

            How it appears in the terminal:

            <pre><code>% <span class="fg-bright-black">This is BRIGHT BLACK!</span></code></pre>
        """

    def bright_red(self, text: str) -> None:
        """Prints full line of bright red text.

        Args:
            text (str): Text to be printed with color.

        Example:
            ```python title="" linenums="1"
            from colorist import bright_red

            bright_red("This is BRIGHT RED!")
            ```

            How it appears in the terminal:

            <pre><code>% <span class="fg-bright-red">This is BRIGHT RED!</span></code></pre>
        """

    def bright_green(self, text: str) -> None:
        """Prints full line of bright green text.

        Args:
            text (str): Text to be printed with color.

        Example:
            ```python title="" linenums="1"

            from colorist import bright_green

            bright_green("This is BRIGHT GREEN!")
            ```

            How it appears in the terminal:

            <pre><code>% <span class="fg-bright-green">This is BRIGHT GREEN!</span></code></pre>
        """

    def bright_yellow(self, text: str) -> None:
        """Prints full line of bright yellow text.

        Args:
            text (str): Text to be printed with color.

        Example:
            ```python title="" linenums="1"
            from colorist import bright_yellow

            bright_yellow("This is BRIGHT YELLOW!")
            ```

            How it appears in the terminal:

            <pre><code>% <span class="fg-bright-yellow">This is BRIGHT YELLOW!</span></code></pre>
        """

    def bright_blue(self, text: str) -> None:
        """Prints full line of bright blue text.

        Args:
            text (str): Text to be printed with color.

        Example:
            ```python title="" linenums="1"
            from colorist import bright_blue

            bright_blue("This is BRIGHT BLUE!")
            ```

            How it appears in the terminal:

            <pre><code>% <span class="fg-bright-blue">This is BRIGHT BLUE!</span></code></pre>
        """

    def bright_magenta(self, text: str) -> None:
        """Prints full line of bright magenta text.

        Args:
            text (str): Text to be printed with color.

        Example:
            ```python title="" linenums="1"
            from colorist import bright_magenta

            bright_magenta("This is BRIGHT MAGENTA!")
            ```

            How it appears in the terminal:

            <pre><code>% <span class="fg-bright-magenta">This is BRIGHT MAGENTA!</span></code></pre>
        """

    def bright_cyan(self, text: str) -> None:
        """Prints full line of bright cyan text.

        Args:
            text (str): Text to be printed with color.

        Example:
            ```python title="" linenums="1"
            from colorist import bright_cyan

            bright_cyan("This is BRIGHT CYAN!")
            ```

            How it appears in the terminal:

            <pre><code>% <span class="fg-bright-cyan">This is BRIGHT CYAN!</span></code></pre>
        """

    def bright_white(self, text: str) -> None:
        """Prints full line of bright white text.

        Args:
            text (str): Text to be printed with color.

        Example:
            ```python title="" linenums="1"
            from colorist import bright_white

            bright_white("This is BRIGHT WHITE!")
            ```

            How it appears in the terminal:

            <pre><code>% <span class="fg-bright-white">This is BRIGHT WHITE!</span></code></pre>
        """



# Copyright 2022 – present, Jakob Bagterp. BSD 3-Clause license and refer to LICENSE file.

from ..constants.ansi import RESET_ALL
from ..model.abc.color import BgColor_ABC, FgColor_ABC
from ..model.abc.effect import Effect_ABC
from ..model.abc.hex import Hex_ABC
from ..model.abc.hsl import HSL_ABC
from ..model.abc.rgb import RGB_ABC


def color(text: str, color: FgColor_ABC | str = "", bg_color: BgColor_ABC | str = "") -> None:
    """Helper function to print a full line of colored text (options for standard ANSI colors in both foreground and background) in the terminal."""

    print(f"{bg_color}{color}{text}{RESET_ALL}")


def effect(text: str, effect: Effect_ABC | str, color: FgColor_ABC | BgColor_ABC | str = "") -> None:
    """Helper function to print a full line of text with custom effect in the terminal."""

    print(f"{color}{effect}{text}{RESET_ALL}")


def normalize_input(input: FgColor_ABC | BgColor_ABC | RGB_ABC | HSL_ABC | Hex_ABC | Effect_ABC | str | None) -> str:
    """Normalize and convert color classes to string of ANSI escape code for print methods, especially converting None values to empty string."""

    return str(input) if input is not None else ""



# Copyright 2022 – present, Jakob Bagterp. BSD 3-Clause license and refer to LICENSE file.

from abc import ABC, abstractmethod

from ... import helper
from ...constants.ansi import RESET_ALL
from ...helper.error import (message_for_hsl_hue_value_error,
                             message_for_hsl_percentage_value_error)
from ...helper.validate import is_valid_hsl_hue, is_valid_percentage
from ..foreground.rgb import ColorRGB
from .rgb import RGB_ABC


class HSL_ABC(ABC):
    """Abstract base class for custom HSL color instances."""

    OFF = RESET_ALL

    __slots__ = ["hue", "saturation", "lightness", "_rgb", "_ansi_code"]

    def __init__(self, hue: float, saturation: float, lightness: float) -> None:
        if not is_valid_hsl_hue(hue):
            raise ValueError(message_for_hsl_hue_value_error(hue))
        if not is_valid_percentage(saturation):
            raise ValueError(message_for_hsl_percentage_value_error("saturation", saturation))
        if not is_valid_percentage(lightness):
            raise ValueError(message_for_hsl_percentage_value_error("lightness", lightness))

        self.hue: float = hue
        self.saturation: float = saturation
        self.lightness: float = lightness

        self._rgb: RGB_ABC = self.convert_hsl_to_rgb()
        self._ansi_code: str = self.generate_ansi_code()

    def __str__(self) -> str:
        return self._ansi_code

    def __repr__(self) -> str:
        return f"H: {self.hue}, S: {self.saturation}, L: {self.lightness}"

    def convert_hsl_to_rgb(self) -> RGB_ABC:
        """Method to convert HSL to RGB color."""

        red, green, blue = helper.convert.hsl_to_rgb(self.hue, self.saturation, self.lightness)
        return ColorRGB(red, green, blue)

    @abstractmethod
    def generate_ansi_code(self) -> str:
        """Method to generate ANSI RGB color sequence."""

        raise NotImplementedError  # pragma: no cover



# Copyright 2022 – present, Jakob Bagterp. BSD 3-Clause license and refer to LICENSE file.

from ... import helper
from ...constants.ansi import AnsiRgbColorSelector
from ..abc.hsl import HSL_ABC


class BgColorHSL(HSL_ABC):
    """Class for custom HSL background color."""

    def __init__(self, hue: float, saturation: float, lightness: float) -> None:
        """
        Args:
            hue (float): Number between `0` and `360` degrees.
            saturation (float): Percentage between `0` and `100` %.
            lightness (float): Percentage between `0` and `100` %.

        Example:
            ```python linenums="1"
            from colorist import BgColorHSL

            bg_steel_gray = BgColorHSL(190, 2, 49)

            print(f"I want to use {bg_steel_gray}steel gray{bg_steel_gray.OFF} background color inside this paragraph")
            ```

            How it appears in the terminal:

            <pre><code>% I want to use <span style="background-color: hsl(190, 2%, 49%)">steel gray</span> background color inside this paragraph</code></pre>
        """

        super().__init__(hue, saturation, lightness)

    def generate_ansi_code(self) -> str:
        return helper.generate.ansi_rgb_color_sequence(AnsiRgbColorSelector.BACKGROUND, self._rgb)



# Copyright 2022 – present, Jakob Bagterp. BSD 3-Clause license and refer to LICENSE file.

from ... import helper
from ...constants.ansi import AnsiRgbColorSelector
from ..abc.hex import Hex_ABC


class BgColorHex(Hex_ABC):
    """Class for custom background defined in Hex color."""

    def __init__(self, hex: str) -> None:
        """
        Args:
            hex (str): Hex color value with or without hashtag, for instance `#B4FBB8` or `B4FBB8`, `#B4F` or `B4F`.

        Example:
            ```python linenums="1"
            from colorist import BgColorHex

            bg_mint_green = BgColorHex("#99ff99")

            print(f"I want to use {bg_mint_green}mint green{bg_mint_green.OFF} background color inside this paragraph")
            ```

            How it appears in the terminal:

            <pre><code>% I want to use <span style="background-color: #99ff99">mint green</span> background color inside this paragraph</code></pre>
        """

        super().__init__(hex)

    def generate_ansi_code(self) -> str:
        return helper.generate.ansi_rgb_color_sequence(AnsiRgbColorSelector.BACKGROUND, self._rgb)



# Copyright 2022 – present, Jakob Bagterp. BSD 3-Clause license and refer to LICENSE file.

import colorsys

from ..helper.error import message_for_hex_value_error


def normalize_colorsys_rgb_to_real_rgb(rgb_colorsys: tuple[float, float, float]) -> tuple[int, int, int]:
    """Since Colorsys outputs RGB values as floats between 0.0 an 1.0, we need to normalize this to a standard RGB scale from 0 to 255."""

    red, green, blue = tuple(int(color * 255) for color in rgb_colorsys)
    return red, green, blue


def normalize_hue_degrees_to_colorsys_hue(hue: float) -> float:
    """When converting HLS or HSV with Colorsys, we need to prepare hue between 0 and 360 degrees to a float between 0.0 and 1.0."""

    return hue / 360.0


def normalize_percentage_to_colorsys_value(value: float) -> float:
    """When converting HLS or HSV with Colorsys, we need to prepare lightness, saturation, etc. percentages between 0% and 100% to a float between 0.0 and 1.0."""

    return value / 100.0


def hsl_to_rgb(hue: float, saturation: float, lightness: float) -> tuple[int, int, int]:
    hue_colorsys = normalize_hue_degrees_to_colorsys_hue(hue)
    saturation_colorsys = normalize_percentage_to_colorsys_value(saturation)
    lightness_colorsys = normalize_percentage_to_colorsys_value(lightness)
    rgb_colorsys = colorsys.hls_to_rgb(hue_colorsys, lightness_colorsys, saturation_colorsys)
    return normalize_colorsys_rgb_to_real_rgb(rgb_colorsys)


def hex_to_rgb(hex: str) -> tuple[int, int, int]:
    """Convert Hex color to RGB. Expects valid Hex color value with or without hashtag, for instance #B4FBB8 or B4FBB8, #B4F or B4F."""

    hex = hex.lstrip("#")
    if len(hex) == 3:
        red, green, blue = tuple(int(hex[i] * 2, 16) for i in (0, 1, 2))
        return red, green, blue
    elif len(hex) == 6:
        red, green, blue = tuple(int(hex[i:i + 2], 16) for i in (0, 2, 4))
        return red, green, blue
    else:
        raise ValueError(message_for_hex_value_error(hex))



# Copyright 2022 – present, Jakob Bagterp. BSD 3-Clause license and refer to LICENSE file.

from ... import helper
from ...model.abc.mkdocstrings import MkDocstringsWrapper_ABC
from ...model.foreground.color import Color


def black(text: str) -> None:
    """Prints full line of black text."""

    helper.print.color(text, color=Color.BLACK)


def red(text: str) -> None:
    """Prints full line of red text."""

    helper.print.color(text, color=Color.RED)


def green(text: str) -> None:
    """Prints full line of green text."""

    helper.print.color(text, color=Color.GREEN)


def yellow(text: str) -> None:
    """Prints full line of yellow text."""

    helper.print.color(text, color=Color.YELLOW)


def blue(text: str) -> None:
    """Prints full line of blue text."""

    helper.print.color(text, color=Color.BLUE)


def magenta(text: str) -> None:
    """Prints full line of magenta text."""

    helper.print.color(text, color=Color.MAGENTA)


def cyan(text: str) -> None:
    """Prints full line of cyan text."""

    helper.print.color(text, color=Color.CYAN)


def white(text: str) -> None:
    """Prints full line of white text."""

    helper.print.color(text, color=Color.WHITE)


class MkDocstringsWrapper(MkDocstringsWrapper_ABC):
    def black(self, text: str) -> None:
        """Prints full line of black text.

        Args:
            text (str): Text to be printed with color.

        Example:
            ```python title="" linenums="1"
            from colorist import black

            black("This is BLACK!")
            ```

            How it appears in the terminal:

            <pre><code>% <span class="fg-black">This is BLACK!</span></code></pre>
        """

    def red(self, text: str) -> None:
        """Prints full line of red text.

        Args:
            text (str): Text to be printed with color.

        Example:
            ```python title="" linenums="1"
            from colorist import red

            red("This is RED!")
            ```

            How it appears in the terminal:

            <pre><code>% <span class="fg-red">This is RED!</span></code></pre>
        """

    def green(self, text: str) -> None:
        """Prints full line of green text.

        Args:
            text (str): Text to be printed with color.

        Example:
            ```python title="" linenums="1"
            from colorist import green

            green("This is GREEN!")
            ```

            How it appears in the terminal:

            <pre><code>% <span class="fg-green">This is GREEN!</span></code></pre>
        """

    def yellow(self, text: str) -> None:
        """Prints full line of yellow text.

        Args:
            text (str): Text to be printed with color.

        Example:
            ```python title="" linenums="1"
            from colorist import yellow

            yellow("This is YELLOW!")
            ```

            How it appears in the terminal:

            <pre><code>% <span class="fg-yellow">This is YELLOW!</span></code></pre>
        """

    def blue(self, text: str) -> None:
        """Prints full line of blue text.

        Args:
            text (str): Text to be printed with color.

        Example:
            ```python title="" linenums="1"
            from colorist import blue

            blue("This is BLUE!")
            ```

            How it appears in the terminal:

            <pre><code>% <span class="fg-blue">This is BLUE!</span></code></pre>
        """

    def magenta(self, text: str) -> None:
        """Prints full line of magenta text.

        Args:
            text (str): Text to be printed with color.

        Example:
            ```python title="" linenums="1"
            from colorist import magenta

            magenta("This is MAGENTA!")
            ```

            How it appears in the terminal:

            <pre><code>% <span class="fg-magenta">This is MAGENTA!</span></code></pre>
        """

    def cyan(self, text: str) -> None:
        """Prints full line of cyan text.

        Args:
            text (str): Text to be printed with color.

        Example:
            ```python title="" linenums="1"
            from colorist import cyan

            cyan("This is CYAN!")
            ```

            How it appears in the terminal:

            <pre><code>% <span class="fg-cyan">This is CYAN!</span></code></pre>
        """

    def white(self, text: str) -> None:
        """Prints full line of white text.

        Args:
            text (str): Text to be printed with color.

        Example:
            ```python title="" linenums="1"
            from colorist import white

            white("This is WHITE!")
            ```

            How it appears in the terminal:

            <pre><code>% <span class="fg-white">This is WHITE!</span></code></pre>
        """



# Copyright 2022 – present, Jakob Bagterp. BSD 3-Clause license and refer to LICENSE file.

from ...model.abc.mkdocstrings import MkDocstringsWrapper_ABC
from ...model.foreground.rgb import ColorRGB
from ...print.general import print_color


def rgb(text: str, red: int, green: int, blue: int) -> None:
    """Prints full line of custom RGB-colored text. Values for red, green, blue can be between `0` and `255`."""

    color_rgb = ColorRGB(red, green, blue)
    print_color(text, color=color_rgb)


class MkDocstringsWrapper(MkDocstringsWrapper_ABC):
    def rgb(self, text: str, red: int, green: int, blue: int) -> None:
        """Prints full line of custom RGB-colored text.

        Args:
            text (str): Text to be printed with color.
            red (int): Number between `0` and `255`.
            green (int): Number between `0` and `255`.
            blue (int): Number between `0` and `255`.

        Example:
            ```python linenums="1"
            from colorist import rgb

            rgb("I want this text in blue RGB colors", 0, 128, 255)
            ```

            How it appears in the terminal:

            <pre><code>% <span style="color: rgb(0, 128, 255)">I want this text in blue RGB colors</span></code></pre>
        """



# Copyright 2022 – present, Jakob Bagterp. BSD 3-Clause license and refer to LICENSE file.

def message_for_rgb_value_error(color: str, value: int) -> str:
    return f"Value for \"{color}\" is {value}, but should be integer between 0 and 255."


def message_for_hsl_hue_value_error(value: float) -> str:
    return f"Value for \"hue\" is {value}, but should be number between 0 and 360."


def message_for_hsl_percentage_value_error(param: str, value: float) -> str:
    return f"Value for \"{param}\" is {value}, but should be number between 0(%) and 100(%)."


def message_for_hex_value_error(value: str) -> str:
    return f"Value {value} isn't valid Hex color code, and should be for instance #B4FBB8 or B4FBB8, #B4F or B4F."



# Copyright 2022 – present, Jakob Bagterp. BSD 3-Clause license and refer to LICENSE file.

from abc import ABC, abstractmethod

from ... import helper
from ...constants.ansi import RESET_ALL
from ...helper.error import message_for_hex_value_error
from ...helper.validate import is_valid_hex_value
from ..foreground.rgb import ColorRGB
from .rgb import RGB_ABC


class Hex_ABC(ABC):
    """Abstract base class for custom Hex color instances."""

    OFF = RESET_ALL

    __slots__ = ["hex", "_rgb", "_ansi_code"]

    def __init__(self, hex: str) -> None:
        if not is_valid_hex_value(hex):
            raise ValueError(message_for_hex_value_error(hex))

        self.hex: str = hex.lower()

        self._rgb: RGB_ABC = self.convert_hex_to_rgb()
        self._ansi_code: str = self.generate_ansi_code()

    def __str__(self) -> str:
        return self._ansi_code

    def __repr__(self) -> str:
        return f"Hex: #{self.hex.lstrip('#')}"

    def convert_hex_to_rgb(self) -> RGB_ABC:
        """Method to convert Hex to RGB color."""

        red, green, blue = helper.convert.hex_to_rgb(self.hex)
        return ColorRGB(red, green, blue)

    @abstractmethod
    def generate_ansi_code(self) -> str:
        """Method to generate ANSI RGB color sequence."""

        raise NotImplementedError  # pragma: no cover



# Copyright 2022 – present, Jakob Bagterp. BSD 3-Clause license and refer to LICENSE file.

from abc import ABC


class MkDocstringsWrapper_ABC(ABC):
    """Abstract base class used to documentation standalone functions now that MkDocstrings (as far as I know) only support reference of functions within classes.

    Should not used for other purposes than documentation."""

    def __init__(self) -> None:
        pass



# Copyright 2022 – present, Jakob Bagterp. BSD 3-Clause license and refer to LICENSE file.

from ... import helper
from ...constants.ansi import AnsiRgbColorSelector
from ..abc.rgb import RGB_ABC


class ColorRGB(RGB_ABC):
    """Class for custom RGB foreground text color."""

    def __init__(self, red: int, green: int, blue: int) -> None:
        """
        Args:
            red (int): Number between `0` and `255`.
            green (int): Number between `0` and `255`.
            blue (int): Number between `0` and `255`.

        Example:
            ```python linenums="1"
            from colorist import ColorRGB

            dusty_pink = ColorRGB(194, 145, 164)

            print(f"I want to use {dusty_pink}dusty pink{dusty_pink.OFF} color inside this paragraph")
            ```

            How it appears in the terminal:

            <pre><code>% I want to use <span style="color: rgb(194, 145, 164)">dusty pink</span> color inside this paragraph</code></pre>
        """

        super().__init__(red, green, blue)

    def generate_ansi_code(self) -> str:
        return helper.generate.ansi_rgb_color_sequence(AnsiRgbColorSelector.FOREGROUND, self)



# Copyright 2022 – present, Jakob Bagterp. BSD 3-Clause license and refer to LICENSE file.

from abc import ABC


class Effect_ABC(ABC):
    """Abstract base class for standard ANSI color classes."""

    BOLD: str
    DIM: str
    UNDERLINE: str
    BLINK: str
    REVERSE: str
    HIDE: str

    BOLD_OFF: str
    DIM_OFF: str
    UNDERLINE_OFF: str
    BLINK_OFF: str
    REVERSE_OFF: str
    HIDE_OFF: str

    OFF: str



# Copyright 2022 – present, Jakob Bagterp. BSD 3-Clause license and refer to LICENSE file.

from ...model.abc.mkdocstrings import MkDocstringsWrapper_ABC
from ...model.foreground.hsl import ColorHSL
from ...print.general import print_color


def hsl(text: str, hue: float, saturation: float, lightness: float) -> None:
    """Prints full line of custom HSL-colored text. Value for hue can be number between `0` and `360` degrees, while saturation and lightness can be a percentage between `0` and `100` %."""

    color_hsl = ColorHSL(hue, lightness, saturation)
    print_color(text, color=color_hsl)


class MkDocstringsWrapper(MkDocstringsWrapper_ABC):
    def hsl(self, text: str, hue: float, saturation: float, lightness: float) -> None:
        """Prints full line of custom HSL-colored text.

        Args:
            text (str): Text to be printed on colored background.
            hue (float): Number between `0` and `360` degrees.
            saturation (float): Percentage between `0` and `100` %.
            lightness (float): Percentage between `0` and `100` %.

        Example:
            ```python linenums="1"
            from colorist import hsl

            hsl("I want this text in green HSL colors", 120, 50, 50)
            ```

            How it appears in the terminal:

            <pre><code>% <span style="color: hsl(120, 50%, 50%)">I want this text in green HSL colors</span></code></pre>
        """



# Copyright 2022 – present, Jakob Bagterp. BSD 3-Clause license and refer to LICENSE file.

__all__ = [
    "Color", "BrightColor", "BgColor", "BgBrightColor", "ColorHex", "BgColorHex", "ColorRGB", "BgColorRGB", "ColorHSL", "BgColorHSL", "Effect",
    "print_color",
    "black", "red", "green", "yellow", "blue", "magenta", "cyan", "white",
    "bright_black", "bright_red", "bright_green", "bright_yellow", "bright_blue", "bright_magenta", "bright_cyan", "bright_white",
    "bg_black", "bg_red", "bg_green", "bg_yellow", "bg_blue", "bg_magenta", "bg_cyan", "bg_white",
    "bg_bright_black", "bg_bright_red", "bg_bright_green", "bg_bright_yellow", "bg_bright_blue", "bg_bright_magenta", "bg_bright_cyan", "bg_bright_white",
    "effect_bold", "effect_dim", "effect_underline", "effect_blink", "effect_reverse", "effect_hide",
    "hex", "rgb", "hsl",
    "bg_hex", "bg_rgb", "bg_hsl"
]

from .model.background.bright_color import BgBrightColor
from .model.background.color import BgColor
from .model.background.hex import BgColorHex
from .model.background.hsl import BgColorHSL
from .model.background.rgb import BgColorRGB
from .model.effect import Effect
from .model.foreground.bright_color import BrightColor
from .model.foreground.color import Color
from .model.foreground.hex import ColorHex
from .model.foreground.hsl import ColorHSL
from .model.foreground.rgb import ColorRGB
from .print.background.bright_color import (bg_bright_black, bg_bright_blue,
                                            bg_bright_cyan, bg_bright_green,
                                            bg_bright_magenta, bg_bright_red,
                                            bg_bright_white, bg_bright_yellow)
from .print.background.color import (bg_black, bg_blue, bg_cyan, bg_green,
                                     bg_magenta, bg_red, bg_white, bg_yellow)
from .print.background.hex import bg_hex
from .print.background.hsl import bg_hsl
from .print.background.rgb import bg_rgb
from .print.effect import (effect_blink, effect_bold, effect_dim, effect_hide,
                           effect_reverse, effect_underline)
from .print.foreground.bright_color import (bright_black, bright_blue,
                                            bright_cyan, bright_green,
                                            bright_magenta, bright_red,
                                            bright_white, bright_yellow)
from .print.foreground.color import (black, blue, cyan, green, magenta, red,
                                     white, yellow)
from .print.foreground.hex import hex
from .print.foreground.hsl import hsl
from .print.foreground.rgb import rgb
from .print.general import print_color
from .version import __version__  # noqa
